#[non_exhaustive]
pub enum Event { Group { pad_group: ZwpTabletPadGroupV2, }, Path { path: String, }, Buttons { buttons: u32, }, Done, Button { time: u32, button: u32, state: WEnum<ButtonState>, }, Enter { serial: u32, tablet: ZwpTabletV2, surface: WlSurface, }, Leave { serial: u32, surface: WlSurface, }, Removed, }
Available on crate feature wayland and Linux only.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Group

group announced

Sent on zwp_tablet_pad_v2 initialization to announce available groups. One event is sent for each pad group available.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event. At least one group will be announced.

Fields



Path

path to the device

A system-specific device path that indicates which device is behind this zwp_tablet_pad_v2. This information may be used to gather additional information about the device, e.g. through libwacom.

The format of the path is unspecified, it may be a device node, a sysfs path, or some other identifier. It is up to the client to identify the string provided.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event.

Fields

path: String

path to local device



Buttons

buttons announced

Sent on zwp_tablet_pad_v2 initialization to announce the available buttons.

This event is sent in the initial burst of events before the zwp_tablet_pad_v2.done event. This event is only sent when at least one button is available.

Fields

buttons: u32

the number of buttons



Done

pad description event sequence complete

This event signals the end of the initial burst of descriptive events. A client may consider the static description of the pad to be complete and finalize initialization of the pad.



Button

physical button state

Sent whenever the physical state of a button changes.

Fields

time: u32

the time of the event with millisecond granularity

button: u32

the index of the button that changed state



Enter

enter event

Notification that this pad is focused on the specified surface.

Fields

serial: u32

serial number of the enter event

tablet: ZwpTabletV2

the tablet the pad is attached to

surface: WlSurface

surface the pad is focused on



Leave

leave event

Notification that this pad is no longer focused on the specified surface.

Fields

serial: u32

serial number of the leave event

surface: WlSurface

surface the pad is no longer focused on



Removed

pad removed event

Sent when the pad has been removed from the system. When a tablet is removed its pad(s) will be removed too.

When this event is received, the client must destroy all rings, strips and groups that were offered by this pad, and issue zwp_tablet_pad_v2.destroy the pad itself.

Implementations



impl Event

pub fn opcode(&self) -> u16

Get the opcode number of this message