Struct ZwpTabletPadV2

pub struct ZwpTabletPadV2 { /* private fields */ }
Available on crate feature wayland and Linux only.
a set of buttons, rings, strips and dials

A pad device is a set of buttons, rings, strips and dials usually physically present on the tablet device itself. Some exceptions exist where the pad device is physically detached, e.g. the Wacom ExpressKey Remote.

Pad devices have no axes that control the cursor and are generally auxiliary devices to the tool devices used on the tablet surface.

A pad device has a number of static characteristics, e.g. the number of rings. These capabilities are sent in an event sequence after the zwp_tablet_seat_v2.pad_added event before any actual events from this pad. This initial event sequence is terminated by a zwp_tablet_pad_v2.done event.

All pad features (buttons, rings, strips and dials) are logically divided into groups and all pads have at least one group. The available groups are notified through the zwp_tablet_pad_v2.group event; the compositor will emit one event per group before emitting zwp_tablet_pad_v2.done.

Groups may have multiple modes. Modes allow clients to map multiple actions to a single pad feature. Only one mode can be active per group, although different groups may have different active modes.

See also the Event enum for this interface.

Implementations



impl ZwpTabletPadV2

pub fn set_feedback(&self, button: u32, description: String, serial: u32)

set compositor feedback

Requests the compositor to use the provided feedback string associated with this button. This request should be issued immediately after a zwp_tablet_pad_group_v2.mode_switch event from the corresponding group is received, or whenever a button is mapped to a different action. See zwp_tablet_pad_group_v2.mode_switch for more details.

Clients are encouraged to provide context-aware descriptions for the actions associated with each button, and compositors may use this information to offer visual feedback on the button layout (e.g. on-screen displays).

Button indices start at 0. Setting the feedback string on a button that is reserved by the compositor (i.e. not belonging to any zwp_tablet_pad_group_v2) does not generate an error but the compositor is free to ignore the request.

The provided string ‘description’ is a UTF-8 encoded string to be associated with this ring, and is considered user-visible; general internationalization rules apply.

The serial argument will be that of the last zwp_tablet_pad_group_v2.mode_switch event received for the group of this button. Requests providing other serials than the most recent one will be ignored.

pub fn destroy(&self)

destroy the pad object

Destroy the zwp_tablet_pad_v2 object. Objects created from this object are unaffected and should be destroyed separately.